@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.100_02';
+our $VERSION = '0.101_01';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -432,7 +432,7 @@ is also taken into account for the non-specular flares.
 
 Atmospheric extinction is calculated according to the article by Daniel
 W.  Green in the July 1992 issue of "International Comet Quarterly", and
-available at L<http://www.cfa.harvard.edu/icq/ICQExtinct.html>. Because
+available at L<http://www.icq.eps.harvard.edu/ICQExtinct.html>. Because
 Heavens Above does not display flares dimmer than a certain magnitude
 (-6 for day flares, and apparently 0 for night flares), it may not
 display a flare that this code predicts. I have no information how
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Fri Jul 20 13:07:17 2018 GMT
+# on Wed Jul 25 13:25:07 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1780,12 +1780,12 @@ __PACKAGE__->status( add => 27374, iridium => 'D', 'Iridium 94', 'Decayed 2018-0
 __PACKAGE__->status( add => 27375, iridium => '+', 'Iridium 95', '' );
 __PACKAGE__->status( add => 27376, iridium => '-', 'Iridium 96', 'Tumbling' );
 __PACKAGE__->status( add => 27450, iridium => 'S', 'Iridium 97', '' );
-__PACKAGE__->status( add => 27451, iridium => 'S', 'Iridium 98', '' );
+__PACKAGE__->status( add => 27451, iridium => '-', 'Iridium 98', 'Tumbling' );
 
 # Summary:
 # Operational [+]: 17
-#       Spare [S]: 16
-#    Tumbling [-]: 37
+#       Spare [S]: 15
+#    Tumbling [-]: 38
 #     Decayed [D]: 27
 
 1;
